@@ -72,10 +72,20 @@ OC.L10N.register(
     "Description: %s" : "Description : %s",
     "Where: %s" : "Où : %s",
     "%1$s via %2$s" : "%1$s via %2$s",
+    "In the past on %1$s for the entire day" : "Dans le passé toute la journée du %1$s ",
     "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Dans une minute le %1$s pour la journée entière","Dans %n minutes le %1$s pour la journée entière","Dans %n minutes le %1$s pour la journée entière"],
     "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Dans une heure le %1$s pour la journée entière","Dans %n heures le %1$s pour la journée entière","Dans %n heures le %1$s pour la journée entière"],
     "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Dans un jour le %1$s pour la journée entière","Dans %n jours le %1$s pour la journée entière","Dans %n jours le %1$s pour la journée entière"],
     "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Dans une semaine le %1$s pour la journée entière","Dans %n semaines le %1$s pour la journée entière","Dans %n semaines le %1$s pour la journée entière"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Dans un mois toute la journée du %1$s","Dans %n mois toute la journée du %1$s","Dans %n mois toute la journée du %1$s"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Dans un an toute la journée du %1$s","Dans %n années toute la journée du %1$s","Dans %n années toute la journée du %1$s"],
+    "In the past on %1$s between %2$s - %3$s" : "Dans le passé le %1$s entre %2$s - %3$s",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Dans une minute le %1$s entre %2$s - %3$s","Dans %n minutes le %1$s entre %2$s - %3$s","Dans %n minutes le %1$s entre %2$s - %3$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Dans une heure le %1$s entre %2$s et %3$s","Dans %n heures le %1$s entre %2$s et %3$s","Dans %n heures le %1$s entre %2$s et %3$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Demain le %1$s entre %2$s et %3$s","Dans %n jours le %1$s entre %2$s et %3$s","Dans %n jours le %1$s entre %2$s et %3$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["La semaine prochaine le %1$s entre %2$s et %3$s","Dans %n semaines le %1$s entre %2$s et %3$s","Dans %n semaines le %1$s entre %2$s et %3$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Dans un mois le %1$s entre %2$s et %3$s","Dans %n mois le %1$s entre %2$s et %3$s","Dans %n mois le %1$s entre %2$s et %3$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["L'an prochain le %1$s entre %2$s et %3$s","Dans %n ans le %1$s entre %2$s et %3$s","Dans %n ans le %1$s entre %2$s et %3$s"],
     "Could not generate when statement" : "Impossible de déterminer quand",
     "Every Day for the entire day" : "Chaque jour pour toute la journée",
     "Every Day for the entire day until %1$s" : "Chaque jour pour toute la journée jusqu'au %1$s",
@@ -112,6 +122,27 @@ OC.L10N.register(
     "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Tous les %1$d ans en %2$s le %3$s entre %4$s - %5$s jusqu'au %6$s",
     "On specific dates for the entire day until %1$s" : "À une date spécifique pour la journée entière jusqu'au %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "À des dates spécifiques entre %1$s et %2$s jusqu'au %3$s",
+    "In the past on %1$s" : "Dans le passé sur %1$s",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["Dans une minute sur %1$s","Dans %n minutes sur %1$s","Dans %n minutes sur %1$s"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["Dans une heure sur %1$s","Dans %n heures sur %1$s","Dans %n sur %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["Demain le %1$s","Dans %n jours le %1$s","Dans %n jours le %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["La semaine prochaine le %1$s","Dans %n semaines le %1$s","Dans %n semaines le %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["Le mois prochain le %1$s","Dans %n mois le %1$s","Dans %n mois le %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["L'an prochain le %1$s","Dans %n ans le %1$s","Dans %n ans le %1$s"],
+    "In the past on %1$s then on %2$s" : "Dans le passé le %1$s puis le %2$s",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Dans une minute le %1$s puis le %2$s","Dans %n minutes le %1$s puis le %2$s","Dans %n minutes le %1$s puis le %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Dans une heure le %1$s puis le %2$s","Dans %n heures le %1$s puis le %2$s","Dans %n heures le %1$s puis le %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Demain le %1$s puis le %2$s","Dans %n jours le %1$s puis le %2$s","Dans %n jours le %1$s puis le %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["La semaine prochaine le %1$s puis le %2$s","Dans %n semaines le %1$s puis le %2$s","Dans %n semaines le %1$s puis le %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Le mois prochain le %1$s puis le %2$s","Dans %n mois le %1$s puis le %2$s","Dans %n mois le %1$s puis le %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["L'an prochain le %1$s puis le %2$s","Dans %n ans le %1$s puis le %2$s","Dans %n ans le %1$s puis le %2$s"],
+    "In the past on %1$s then on %2$s and %3$s" : "Dans le passé le %1$s puis le %2$s et %3$s",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Dans une minute le %1$s puis le %2$s et %3$s","Dans %n minutes le %1$s puis le %2$s et %3$s","Dans %n minutes le %1$s puis le %2$s et %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Dans une heure le %1$s puis le %2$s et %3$s","Dans %n heures le %1$s puis le %2$s et %3$s","Dans %n heures le %1$s puis le %2$s et %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Demain le %1$s puis le %2$s et %3$s","Dans %n jours le %1$s puis le %2$s et %3$s","Dans %n jours le %1$s puis le %2$s et %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["La semaine prochaine le %1$s puis le %2$s et %3$s","Dans %n semaines le %1$s puis le %2$s et %3$s","Dans %n semaines le %1$s puis le %2$s et %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Dans un mois le %1$s puis le %2$s et %3$s","Dans %n mois le %1$s puis le %2$s et %3$s","Dans %n mois le %1$s puis le %2$s et %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Dans un an sur %1$spuis sur %2$s et %3$s","Dans %n années sur %1$s puis sur %2$s et %3$s","Dans %n années sur %1$s puis sur %2$s et %3$s"],
     "Could not generate next recurrence statement" : "Impossible de déterminer la prochaine récurrence",
     "Cancelled: %1$s" : "Annulé : %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" a été annulé(e)",
@@ -159,11 +190,11 @@ OC.L10N.register(
     "Third" : "Troisième",
     "Fourth" : "Quatrième",
     "Fifth" : "Cinquième",
-    "Last" : "Dernière",
-    "Second Last" : "Avant dernier",
-    "Third Last" : "Antépénultième",
-    "Fourth Last" : "Pré-antépénultième",
-    "Fifth Last" : "Cinq Derniers",
+    "Last" : "Dernièr",
+    "Second Last" : "Avant-dernier",
+    "Third Last" : "Troisième dernier",
+    "Fourth Last" : "Quatrième dernier",
+    "Fifth Last" : "Cinquième dernier",
     "Contacts" : "Contacts",
     "{actor} created address book {addressbook}" : "{actor} a créé le carnet d'adresses {addressbook}",
     "You created address book {addressbook}" : "Vous avez créé le carnet d'adresses {addressbook}",
@@ -219,6 +250,10 @@ OC.L10N.register(
     "Completed on %s" : "Terminé le %s",
     "Due on %s by %s" : "Echéance le %s pour %s",
     "Due on %s" : "Echéance le %s",
+    "Example event - open me!" : "Exemple d'événement - ouvrez-moi !",
+    "System Address Book" : "Carnet d'adresses du système",
+    "The system address book contains contact information for all users in your instance." : "Le carnet d'adresses du système contient les informations de contact de tous les utilisateurs de votre instance.",
+    "Enable System Address Book" : "Activer le carnet d'adresses du système",
     "DAV system address book" : "Carnet d'adresses système DAV",
     "No outstanding DAV system address book sync." : "Pas de synchronisation DAV en cours du carnet d'adresses système.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La synchronisation du carnet d'adresses système DAV n'a pas encore été effectuée car votre instance a plus de 1 000 utilisateurs ou parce qu'une erreur est survenue. Merci de l'exécuter manuellement en tapant la commande \"occ dav:sync-system-addressbook\".",
@@ -256,6 +291,25 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Choisissez une heure de début pour {dayName}",
     "Pick a end time for {dayName}" : "Choisissez une heure de fin pour {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Définir automatiquement le statut « Ne pas déranger » en dehors des heures de disponibilités pour désactiver toutes les notifications.",
+    "Cancel" : "Annuler",
+    "Import" : "Importation",
+    "Error while saving settings" : "Erreur lors de l'enregistrement des paramètres",
+    "Contact reset successfully" : "Contact réinitialisé avec succès",
+    "Error while resetting contact" : "Erreur lors de la remise à zéro du contact",
+    "Contact imported successfully" : "Contact importé avec succès",
+    "Error while importing contact" : "Erreur lors de l'importation du contact",
+    "Import contact" : "Importer un contact",
+    "Reset to default" : "Restaurer les valeurs par défaut",
+    "Import contacts" : "Importer des contacts",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importer un nouveau fichier .vcf supprimera le contact par défaut existant et le remplacera. Voulez-vous continuer ?",
+    "Failed to save example event creation setting" : "Échec de la sauvegarde du paramètre de l'exemple de création d'événement",
+    "Failed to upload the example event" : "Échec du téléversement de l'exemple d'événement",
+    "Custom example event was saved successfully" : "L'exemple d'événement personnalisé a bien été enregistré",
+    "Failed to delete the custom example event" : "Échec de la suppression de l'exemple d'événement personnalisé ",
+    "Custom example event was deleted successfully" : "L'exemple de contenu personnalisé a bien été supprimé",
+    "Import calendar event" : "Importer l'événement du calendrier",
+    "Uploading a new event will overwrite the existing one." : "Charger un nouvel événement qui va remplacer l'actuel.",
+    "Upload event" : "Téléverser un événement",
     "Availability" : "Disponibilités",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si vous configurez vos heures de travail, les autres personnes verront si vous êtes disponible quand ils planifient une réunion.",
     "Absence" : "Absence",
@@ -272,14 +326,12 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Envoyez également des notifications de rappel aux personnes partageant le calendrier",
     "Reminders are always sent to organizers and attendees." : "Des rappels sont toujours envoyés aux organisateurs et aux participants.",
     "Enable notifications for events via push" : "Activer les notifications push pour les évènements",
+    "Example content" : "Exemple de contenu",
+    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Les exemples de contenu servent à présenter les fonctionnalités de Nextcloud. Le contenu par défaut est fourni avec Nextcloud et peut être remplacé par du contenu personnalisé.",
     "There was an error updating your attendance status." : "Une erreur s'est produite lors de la mise à jour de votre statut de présence.",
     "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
     "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
     "Tentative" : "Tentative",
-    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès.",
-    "Time:" : "Heure :",
-    "Could not open file" : "Impossible d'ouvrir le fichier",
-    "Invalid chunk name" : "Nom de morceau invalide",
-    "Could not rename part file assembled from chunks" : "Impossible de renommer le fichier partiel à partir des morceaux"
+    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
