@@ -13,6 +13,7 @@ OC.L10N.register(
     "Restored by {user}" : "Вратено од {user}",
     "Renamed by {user}" : "Преименувано од {user}",
     "Moved by {user}" : "Преместено од {user}",
+    "\"remote account\"" : "\"оддалечен корисник\"",
     "You created {file}" : "Креиравте {file}",
     "You created an encrypted file in {file}" : "Креиравте шифрирана датотека во {file}",
     "{user} created {file}" : "{user} креираше {file}",
@@ -42,11 +43,22 @@ OC.L10N.register(
     "Files" : "Датотеки",
     "A file or folder has been <strong>changed</strong>" : "Датотека или папка беше <strong>променета</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Датотека или папка која е означена како омилена беше <strong>променета</strong>",
-    "Upload (max. %s)" : "Префрлање (макс. %s)",
+    "Failed to authorize" : "Неуспешна авторизација",
+    "Invalid folder path" : "Невалидна патека до папка",
+    "Folder not found" : "Папката не е пронајдена",
+    "The file cannot be found" : "Датотеката неможе да биде пројандена",
+    "The destination path does not exist: %1$s" : "Патеката не постои: %1$s",
+    "You do not have permission to create a file at the specified location" : "Немате дозвола да креирате датотека на специфираната локација",
+    "The file could not be converted." : "Датотеката неможе да се конвертира.",
+    "Favorite files" : "Омилени датотеки",
+    "No favorites" : "Нема омилени",
+    "More favorites" : "Повеќе омилени",
     "Accept" : "Прифати",
     "Reject" : "Одбиј",
     "Incoming ownership transfer from {user}" : "Барање за трансфер на сопственост од {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Дали прифаќате {path}?\n\nЗабелешка: Процесот на трансфер откога ќе прифатите може да трае и повеќе од 1 час.",
+    "Ownership transfer denied" : "Одбиен трансфер на сопственост",
+    "Your ownership transfer of {path} was denied by {user}." : "Барањето за трансфер на сопственост на {path} е одбиен од {user}.",
     "Ownership transfer failed" : "Неуспешен трансфер на сопственост",
     "Your ownership transfer of {path} to {user} failed." : "Неуспешен трансфер на сопственост на {path} до {user}.",
     "The ownership transfer of {path} from {user} failed." : "Неуспешен трансфер на сопственост на {path} од {user}.",
@@ -54,52 +66,58 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Вашиот транфер на сопственост на {path} до {user} е комплетиран.",
     "The ownership transfer of {path} from {user} has completed." : "Трансферот на сопственост на {path} од {user} е комплетиран.",
     "in %s" : "во %s",
+    "Transferred from %1$s on %2$s" : "Трансфер од %1$s на %2$s",
+    "Files compatibility" : "Компатибилност со датотеки",
     "File Management" : "Датотеки",
-    "Current directory path" : "Патека до оваа папка",
     "Home" : "Дома",
     "Target folder does not exist any more" : "Папката не постои повеќе",
     "Reload current directory" : "Превчитај ја повторно моменталната папка",
     "Go to the \"{dir}\" directory" : "Оди до \"{dir}\" папката",
-    "Drag and drop files here to upload" : "Повлечи и испушти датотеки за прикачување",
+    "Current directory path" : "Патека до оваа папка",
     "Your have used your space quota and cannot upload files anymore" : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки",
-    "You don’t have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки",
+    "Drag and drop files here to upload" : "Повлечи и испушти датотеки за прикачување",
     "Favorite" : "Омилени",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
-    "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
-    "Rename file" : "Преименувај датотека",
+    "Back" : "Назад",
     "Filename" : "Име на датотека",
     "Folder name" : "Име на папка",
     "This node is unavailable" : "Нодот е недостапен",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Преименувано \"{oldName}\" во \"{newName}\"",
+    "Rename file" : "Преименувај датотека",
+    "Folder" : "Папка",
     "Pending" : "Чека",
+    "Unknown date" : "Непознат датум",
     "Clear filter" : "Исчисти филтри",
     "Modified" : "Променето",
+    "Search everywhere" : "Барај насекаде",
     "Type" : "Вид",
+    "Active filters" : "Активни филтри",
+    "Remove filter" : "Острани филтер",
     "Total rows summary" : "Резиме на вкупно редови",
     "Name" : "Име",
+    "File type" : "Вид на датотека",
     "Size" : "Големина",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акција е успешно извршена",
+    "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
     "Actions" : "Акции",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\" не успеа на некои елементи",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акцијата е успешно извршена",
-    "{count} selected" : "{count} селектирани",
+    "(selected)" : "(означени)",
     "List of files and folders." : "Листа на датотеки и папки.",
+    "You have used your space quota and cannot upload files anymore." : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки.",
     "Column headers with buttons are sortable." : "Насловите на колоните со копчиња се сортираат.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Оваа листа не е целосно прикажана поради заштеда на перформанси. Датотеките ќе се прикажуваат додека се движите низ листата.",
     "File not found" : "Датотеката не е пронајдена",
-    "Storage information" : "Информации за складиште",
+    "_{count} selected_::_{count} selected_" : ["{count} означена","{count} означени"],
+    "Search globally" : "Пребарај глобално",
     "{usedQuotaByte} used" : "искористено {usedQuotaByte}",
     "{used} of {quota} used" : "Искористени {used} од {quota}",
     "{relative}% used" : "искористено {relative}% ",
     "Could not refresh storage stats" : "Неможе да се ажурира статистиката за складиштата",
     "Your storage is full, files can not be updated or synced anymore!" : "Вашето складиште е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
-    "Create" : "Креирај",
+    "Storage information" : "Информации за складиште",
     "New folder" : "Нова папка",
     "Create new folder" : "Креирај нова папка",
+    "This name is already in use." : "Името е веќе во употреба.",
+    "Create" : "Креирај",
     "Submit" : "Испрати",
-    "Transfer ownership of a file or folder" : "Трансфер на сопственост на датотека или папка",
-    "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
-    "Change" : "Измени",
-    "New owner" : "Нов сопственик",
     "Choose a file or folder to transfer" : "Избери датотека или папка за трансфер",
     "Transfer" : "Трансфер",
     "Transfer {path} to {userid}" : "Трансфер {path} до {userid}",
@@ -107,14 +125,12 @@ OC.L10N.register(
     "Unknown error" : "Непозната грешка",
     "Ownership transfer request sent" : "Испратено барање за трансфер на сопственост",
     "Cannot transfer ownership of a file or folder you do not own" : "Неможете да направите трансвер на сопственот на папка која не е ваша",
+    "Transfer ownership of a file or folder" : "Трансфер на сопственост на датотека или папка",
+    "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
+    "Change" : "Измени",
+    "New owner" : "Нов сопственик",
     "Select file or folder to link to" : "Изберете датотека или папка за линк до",
     "Choose {file}" : "Избери {file}",
-    "New" : "Ново",
-    "Loading current folder" : "Вчитување на моменталната папка",
-    "Retry" : "Обидете се повторно",
-    "No files in here" : "Тука нема датотеки",
-    "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
-    "Go back" : "Назад",
     "Share" : "Сподели",
     "Shared by link" : "Споделено со линк",
     "Shared" : "Споделено",
@@ -124,34 +140,55 @@ OC.L10N.register(
     "Operation is blocked by access control" : "Операцијата е блокирана од контролата на пристап",
     "Error during upload: {message}" : "Грешка при прикачување: {message}",
     "Unknown error during upload" : "Непозната грешка при прикачување",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
+    "Loading current folder" : "Вчитување на моменталната папка",
+    "Retry" : "Обидете се повторно",
+    "No files in here" : "Тука нема датотеки",
+    "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
+    "Go back" : "Назад",
     "Views" : "Прегледи",
     "Files settings" : "Параметри за датотеки",
+    "Your files" : "Ваши датотеки",
+    "Open in files" : "Отвори во датотеките",
     "File cannot be accessed" : "Неможе да се пристапи до датотеката",
+    "Search for files" : "Пребарај датотеки",
+    "Clipboard is not available" : "Клипбордот не е достапен",
+    "WebDAV URL copied to clipboard" : "CalDAV линкот е копиран",
+    "Default view" : "Стандарден поглед",
+    "All files" : "Сите датотеки",
+    "Personal files" : "Лични датотеки",
     "Sort favorites first" : "Прво омилените",
     "Show hidden files" : "Прикажи сокриени датотеки",
     "Crop image previews" : "Исечи ја сликата за преглед",
-    "Enable the grid view" : "Овозможи поглед во мрежа",
     "Additional settings" : "Дополнителни параметри",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV адреса",
     "Copy to clipboard" : "Копирај во клипборд",
     "Use this address to access your Files via WebDAV" : "Користи ја оваа адреса за пристап до вашите датотеки преку WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако имате овозможено 2FA, мора да креирате и користите нова лозинка за апликација со кликнување овде.",
-    "Clipboard is not available" : "Клипбордот не е достапен",
-    "WebDAV URL copied to clipboard" : "CalDAV линкот е копиран",
+    "Warnings" : "Предупредувања",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Rename a file" : "Преименувај датотека",
+    "Delete a file" : "Избриши датотека",
+    "Navigation" : "Навигација",
+    "View" : "Поглед",
+    "You" : "Вас",
+    "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
+    "Owner" : "Сопственик",
     "Remove from favorites" : "Отстрани од фаворити",
     "Add to favorites" : "Додади во фаворити",
     "Tags" : "Ознаки",
-    "You" : "Вие",
-    "Unable to change the favourite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
-    "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
+    "Blank" : "Празно",
+    "Unable to create new file from template" : "Неможе да се креира датотека од шаблон",
     "Pick a template for {name}" : "Избери шаблон за {name}",
     "Create a new file with the selected template" : "Креирај нова датотека со избраниот шаблон",
     "Creating file" : "Креирање на датотека",
-    "Blank" : "Празно",
-    "Unable to create new file from template" : "Неможе да се креира датотека од шаблон",
-    "Delete permanently" : "Избриши",
+    "Save as {displayName}" : "Зачувај како {displayName}",
+    "Save as …" : "Зачувај како ...",
+    "Converting files …" : "Конвертирање датотеки …",
+    "Deletion cancelled" : "Бришењето е откажано",
     "Disconnect storage" : "Исклучи складиште",
+    "Delete permanently" : "Избриши",
     "Delete file" : "Избриши датотека",
     "Delete files" : "Избриши датотеки",
     "Delete folder" : "Избриши папка",
@@ -159,9 +196,9 @@ OC.L10N.register(
     "Delete" : "Избриши",
     "Confirm deletion" : "Потврди бришење",
     "Cancel" : "Откажи",
-    "Edit file locally" : "Уреди ја датотеката локално",
-    "Failed to redirect to client" : "Неуспешно пренасочување кон клиентот",
-    "Edit locally" : "Уреди локално",
+    "Download" : "Преземи",
+    "Destination is not a folder" : "Дестинацијата не е папка",
+    "This file/folder is already in that directory" : "Оваа папка/датотека се наоѓа веќе во таа папка",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможете да преместите датотека/папка во себеси или во подпапка во себеси",
     "(copy)" : "(копирај)",
     "(copy %n)" : "(копирај %n)",
@@ -177,6 +214,9 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
     "Open folder {displayName}" : "Отвори папка {displayName}",
     "Open in Files" : "Отвори во датотеките",
+    "Open locally" : "Отвори локално",
+    "Failed to redirect to client" : "Неуспешно пренасочување кон клиентот",
+    "Open file locally" : "Отвори ја датотеката локално",
     "Rename" : "Преименувај",
     "Open details" : "Отвори детали",
     "View in folder" : "Погледни во папката",
@@ -191,34 +231,34 @@ OC.L10N.register(
     "Videos" : "Видеа",
     "Created new folder \"{name}\"" : "Креирана нова папка \"{name}\"",
     "Unable to initialize the templates directory" : "Не може да се иницијализира папка за шаблони",
+    "Create templates folder" : "Креирај папка за шаблони",
     "Templates" : "Шаблони",
     "One of the dropped files could not be processed" : "Една од испуштените датотеки неможе да се процесоира",
     "Some files could not be moved" : "Некои датотеки не можат да се преместат",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Неможе да се преименува \"{oldName}\", не постои повеќе",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
+    "Could not rename \"{oldName}\"" : "Неможе да се преименува \"{oldName}\"",
     "This operation is forbidden" : "Операцијата не е дозволена",
     "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} датотека","{fileCount} датотеки"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 датотека и {folderCount} папки","1 датотека и {folderCount} папки"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} датотека и 1 папка","{fileCount} датотеки и 1 папка"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} датотеки и {folderCount} папки",
+    "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
+    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
+    "Filename must not be empty." : "Името на датотеката не може да биде празно.",
     "No favorites yet" : "Сеуште нема фаворити",
     "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
-    "All files" : "Сите датотеки",
     "List of your files and folders." : "Листа на вашите датотеки и папки.",
     "All folders" : "Сите папки",
-    "Personal Files" : "Персонални датотеки",
+    "No personal files found" : "Не се пронајдени лични датотеки ",
     "Recent" : "Неодамнешни",
     "List of recently modified files and folders." : "Листа на скоро изменети датотеки и папки.",
     "No recently modified files" : "Нема скоро изменети датотеки",
     "Files and folders you recently modified will show up here." : "Датотеките и папките кои скоро ќе ги измените ќе се појават тука.",
-    "You do not have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки овде",
+    "Search" : "Барај",
     "No entries found in this folder" : "Нема ништо во оваа папка",
     "Select all" : "Избери се",
     "Upload too large" : "Фајлот кој се вчитува е преголем",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
     "File could not be found" : "Неможе да се пронајде датотеката",
-    "Download" : "Преземи",
     "Show list view" : "Прикажи поглед во листа",
     "Show grid view" : "Прикажи поглед во мрежа",
     "Close" : "Затвори",
@@ -240,6 +280,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Грешка при составување на парчиња, статусен код {status}",
     "Choose target folder" : "Избери папка",
     "Set reminder" : "Постави потсетник",
+    "Edit locally" : "Уреди локално",
     "Open" : "Отвори",
     "Could not load info for file \"{file}\"" : "Неможе да се вчитаат информации за датотеката \"{file}\"",
     "Details" : "Детали:",
@@ -256,9 +297,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Копирана {origin} во {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирана {origin} и {nbfiles} други датотеки во {destination}",
     "{newName} already exists" : "{newName} веќе постои",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Неможе да се преименува \"{fileName}\", датотеката не постои",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
-    "Could not rename \"{fileName}\"" : "Неможе да се преименува \"{fileName}\"",
     "Could not create file \"{file}\"" : "Неможе да се креира датотека \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Неможе да се креира датотека \"{file}\" бидејќи веќе постои",
     "Could not create folder \"{dir}\" because it already exists" : "Неможе да се креира папка \"{dir}\" бидејќи веќе постои",
@@ -266,11 +304,11 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Грешка при бришење на датотека \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултати од пребарувањето на други места за {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Внесете повеќе од два карактери за да пребарувате во другите папки",
-    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
-    "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
     "{dirs} and {files}" : "{dirs} и {files}",
     "_including %n hidden_::_including %n hidden_" : ["вклучувајќи %n скриена","вклучувајќи %n скриени"],
+    "You do not have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки овде",
     "_Uploading %n file_::_Uploading %n files_" : ["Прикачување %n датотека","Прикачување на %n датотеки"],
+    "New" : "Ново",
     "New file/folder menu" : "Мени Нова датотека/папка",
     "Select file range" : "Избери опсег на датотеки",
     "{used}%" : "{used}%",
@@ -288,33 +326,21 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Надворешното складиште \"{mountPoint}\" е скоро исполнето ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Вашето складиште е скоро исполнето ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["содржи '{filter}'","содржи '{filter}'"],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
     "Path" : "Патека",
     "_%n byte_::_%n bytes_" : ["%n бајт","%n бајти"],
-    "Favorited" : "Омилени",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
     "Upload file" : "Прикачи датотека",
-    "Not favorited" : "Нема фаворити",
     "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
-    "\"remote user\"" : "\"далечен корисник\"",
-    "{newName} already exists." : "{newName} веќе постои.",
-    "Name cannot be empty" : "Името неможе да биде празно",
-    "Another entry with the same name already exists" : "Друг запис со исто име веќе постои",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Неможе да се преименува \"{oldName}\", не постои повеќе",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
-    "Could not rename \"{oldName}\"" : "Неможе да се преименува \"{oldName}\"",
-    "Storage informations" : "Информации за складиштето",
-    "Choose file" : "Избери датотека",
-    "Go to the previous folder" : "Врати се на предходната папка",
-    "Open the files app settings" : "Отвори ги параметрите за датотеките",
-    "You might not have have permissions to view it, ask the sender to share it" : "Можеби немате дозвола за преглед, прашајте го испраќачот за споделувањето",
-    "The files is locked" : "Датотекатите се заклучени",
-    "Create new templates folder" : "Креирај нова папка за шаблони",
-    "List of favorites files and folders." : "Листа на омилени датотеки и папки.",
-    "Toggle %1$s sublist" : "Вклучи %1$s подлисти",
+    "Upload (max. %s)" : "Префрлање (макс. %s)",
+    "Enable the grid view" : "Овозможи поглед во мрежа",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} датотека","{fileCount} датотеки"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 датотека и {folderCount} папки","1 датотека и {folderCount} папки"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} датотека и 1 папка","{fileCount} датотеки и 1 папка"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} датотеки и {folderCount} папки",
+    "Personal Files" : "Лични датотеки",
     "Text file" : "Текстуална датотека",
-    "New text file.txt" : "Нова текстуална датотека file.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)"
+    "New text file.txt" : "Нова текстуална датотека file.txt"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
