@@ -1,33 +1,16 @@
 <?php
-/**
- * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
 
+/**
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
 namespace OCA\Files_Sharing\Migration;
 
 use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\Migration\IOutput;
 use OCP\Migration\IRepairStep;
-use OCP\Share;
+use OCP\Share\IShare;
 
 /**
  * Class OwncloudGuestShareType
@@ -39,7 +22,7 @@ class OwncloudGuestShareType implements IRepairStep {
 	/** @var IDBConnection */
 	private $connection;
 
-	/** @var  IConfig */
+	/** @var IConfig */
 	private $config;
 
 
@@ -68,15 +51,14 @@ class OwncloudGuestShareType implements IRepairStep {
 
 		$query = $this->connection->getQueryBuilder();
 		$query->update('share')
-			->set('share_type',  $query->createNamedParameter(Share::SHARE_TYPE_GUEST))
-			->where($query->expr()->eq('share_type', $query->createNamedParameter(Share::SHARE_TYPE_EMAIL)));
+			->set('share_type', $query->createNamedParameter(IShare::TYPE_GUEST))
+			->where($query->expr()->eq('share_type', $query->createNamedParameter(IShare::TYPE_EMAIL)));
 		$query->execute();
 	}
 
 	protected function shouldRun() {
 		$appVersion = $this->config->getAppValue('files_sharing', 'installed_version', '0.0.0');
-		return in_array($appVersion, ['0.10.0']) ||
+		return $appVersion === '0.10.0' ||
 			$this->config->getAppValue('core', 'vendor', '') === 'owncloud';
 	}
-
 }
