@@ -110,8 +110,6 @@ OC.L10N.register(
     "A tag with the same name already exists" : "En tagg med samma namn finns redan",
     "Failed to load tags for file" : "Kunde inte läsa in taggar för filen",
     "Failed to set tag for file" : "Kunde inte sätta tagg för filen",
-    "Failed to delete tag for file" : "Kunde inte ta bort tagg för filen",
-    "This file has the tag {tag}" : "Den här filen har taggen {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Den här filen har taggarna {firstTags} och {lastTag}"
+    "Failed to delete tag for file" : "Kunde inte ta bort tagg för filen"
 },
 "nplurals=2; plural=(n != 1);");
