@@ -31,8 +31,12 @@ OC.L10N.register(
     "Assistant results" : "어시스턴트 결과",
     "Show result" : "결과 표시",
     "Delete task" : "결과 삭제",
+    "Overwrite the file and save the current changes" : "파일을 덮어쓰고 현재의 변경사항을 저장하기",
+    "Discard the current changes and load the latest version" : "현재의 변경사항을 취소하고 최신 버전을 불러오기",
     "Reload" : "새로 고침",
+    "The document could not be loaded. Please check your internet connection." : "문서를 가져올 수 없습니다. 인터넷 연결을 확인해주십시오.",
     "Reconnect" : "재연결",
+    "You've been disconnected from the server." : "서버와의 연결이 끊어졌습니다.",
     "This file is opened read-only as it is currently locked by {user}." : "이 파일은 {user}에 의해 잠겨 있으므로 읽기 전용으로 열립니다.",
     "Close outline view" : "개요 닫기",
     "Outline" : "개요",
@@ -63,7 +67,6 @@ OC.L10N.register(
     "Unsaved changes" : "저장하지 않은 변경 사항",
     "Save document" : "문서 저장",
     "Last saved" : "마지막 저장",
-    "Connection failed." : "연결에 실패했습니다.",
     "Formatting and shortcuts" : "서식 및 단축키",
     "Speed up your writing with simple shortcuts." : "간단한 단축키들로 글쓰기 속도를 높이세요.",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "마크다운 구문을 입력하거나 아래의 키보드 단축키를 사용하세요.",
@@ -123,6 +126,7 @@ OC.L10N.register(
     "Link to file or folder" : "파일이나 폴더로 링크",
     "Link to website" : "웹사이트로 링크",
     "Update link" : "링크 갱신",
+    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\"(이)가 선택되었습니다.",
     "_%n word_::_%n words_" : ["%n개 단어"],
     "_%n char_::_%n chars_" : ["%n개 글자"],
     "Remaining actions" : "남은 동작",
@@ -197,6 +201,8 @@ OC.L10N.register(
     "Option" : "옵션",
     "Formatting" : "서식",
     "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
+    "Choose" : "선택",
+    "Choose {file}" : "{file} 선택",
     "Add folder description" : "폴더 설명 추가",
     "\"{name}\" already exist!" : "\"{name}\" (이)가 이미 존재합니다!",
     "Created \"{name}\"" : "\"{name}\" 생성함",
@@ -209,16 +215,12 @@ OC.L10N.register(
     "Document has been changed outside of the editor. The changes cannot be applied" : "문서가 에디터 밖에서 변경되었습니다. 변경사항이 적용되지 않습니다.",
     "Document could not be loaded. Please check your internet connection." : "문서를 가져올 수 없습니다. 인터넷 연결을 확인해주십시오.",
     "Document idle for {timeout} minutes, click to continue editing" : "문서가 {timeout}분동안 유휴 상태입니다. 클릭하여 편집을 계속하세요.",
-    "Show author colors" : "작성자 색상 표시",
-    "Author colors are only shown until everyone has closed the document." : "작성자 색상은 모두가 문서를 닫았을 때까지만 표시됩니다.",
     "Detect language" : "언어 감지",
     "Callouts" : "설명선",
     "Info" : "정보",
     "Success" : "성공",
     "Warning" : "경고",
     "Danger" : "위험",
-    "Control" : "제어:",
-    "Add notes, lists or links …" : "메모나 목록, 링크를 추가하세요...",
     "Start writing, or try '/' to add, '@' to mention…" : "글쓰기를 시작하거나, '/' 로 추가하고 '@'로 언급하세요..."
 },
 "nplurals=1; plural=0;");
