@@ -1,16 +1,21 @@
 OC.L10N.register(
     "text",
     {
+    "File not found" : "Файл олдсонгүй",
     "Translate" : "Орчуулга",
     "Guest" : "Зочин",
     "Saved" : "Хадгалах",
+    "Link" : "Холбоос",
+    "Undo" : "буцах",
     "Cancel" : "Цуцлах",
     "URL" : "URL",
     "to" : "Дуусах нь",
     "Replace" : "Солих",
+    "Upload" : "байршуулах",
     "Edit" : "засварлах",
     "Source code" : "эх үүсвэр талын код",
-    "Undo" : "буцах",
+    "Details" : "Дэлгэрэнгүй",
+    "Choose" : "Сонгох",
     "Info" : "Info",
     "Warning" : "Warning"
 },
