@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Přihlášení se nedaří dokončit",
     "State token missing" : "Chybí stavový token",
     "Your login token is invalid or has expired" : "Váš přihlašovací token není platný nebo jeho platnost skončila",
+    "Please use original client" : "Prosím použijte původního klienta",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Toto komunitní vydání Nextcloud není podporováno a push oznámení jsou proto omezená.",
     "Login" : "Přihlásit",
     "Unsupported email length (>255)" : "Nepodporovaná délka e-mailu (>255)",
@@ -34,7 +35,7 @@ OC.L10N.register(
     "Could not reset password because the token is expired" : "Heslo není možné resetovat, protože platnost tokenu skončila",
     "Could not reset password because the token is invalid" : "Heslo není možné resetovat, protože token není platný",
     "Password is too long. Maximum allowed length is 469 characters." : "Heslo je příliš dlouhé. Délka může být nejvýše 469 znaků.",
-    "%s password reset" : "reset hesla %s",
+    "%s password reset" : "Reset hesla uživatele %s",
     "Password reset" : "Reset hesla",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na tlačítko níže. Pokud jste o resetování hesla nežádali, tento e-mail ignorujte.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na následující odkaz. Pokud jste o reset nežádali, tento e-mail ignorujte.",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "Task not found" : "Úkol nenalezen",
     "Internal error" : "Vnitřní chyba",
     "Not found" : "Nenalezeno",
+    "Node is locked" : "Uzel je uzamčen",
     "Bad request" : "Chybný požadavek",
     "Requested task type does not exist" : "Požadovaný typ úkolu neexistuje",
     "Necessary language model provider is not available" : "Nezbytný poskytovatel jazykového modelu není k dsipozici",
@@ -51,6 +53,11 @@ OC.L10N.register(
     "No translation provider available" : "Není k dispozici žádný poskytovatel překladu",
     "Could not detect language" : "Nepodařilo se zjistit jazyk",
     "Unable to translate" : "Nedaří se přeložit",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Krok opravy:",
+    "Repair info:" : "Informace o opravě:",
+    "Repair warning:" : "Varování ohledně opravy:",
+    "Repair error:" : "Chyba opravy:",
     "Nextcloud Server" : "Server Nextcloud",
     "Some of your link shares have been removed" : "Některá vaše sdílení odkazem byla odstraněna",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvůli chybě v zabezpečení bylo třeba odstranit některé z sdílení odkazem. Další informace viz odkaz.",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Aby bylo možné zvýšit limit počtu uživatelských účtů, zadejte v aplikaci podpora svůj klíč k předplatnému. Toto také zpřístupní veškeré další výhody, které nabízí Nextcloud pro podniky a je velmi doporučeno pro provozování ve firmách.",
     "Learn more ↗" : "Zjistit víc ↗",
     "Preparing update" : "Příprava pro aktualizaci",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Krok opravy:",
-    "Repair info:" : "Informace o opravě:",
-    "Repair warning:" : "Varování ohledně opravy:",
-    "Repair error:" : "Chyba opravy:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Zaktualizujte z příkazového řádku, protože aktualizování z webového prohlížeče je vypnuté ve vašem config.php.",
     "Turned on maintenance mode" : "Přepnuto do režimu údržby",
     "Turned off maintenance mode" : "Přepnuto zpět z režimu údržby",
@@ -79,6 +81,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekompatibilní)",
     "The following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
     "Already up to date" : "Už je aktuální",
+    "Windows Command Script" : "Windows cmd skript",
+    "Electronic book document" : "Dokument – elektronická knížka",
+    "TrueType Font Collection" : "Sada TrueType písem",
+    "Web Open Font Format" : "Písmo ve formátu Web Open",
+    "GPX geographic data" : "Geografická data GPX",
+    "Gzip archive" : "Gzip archiv",
+    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
+    "Java source code" : "Zdrojový kód v Javě",
+    "JavaScript source code" : "Zdrojový kód v JavaScriptu",
+    "JSON document" : "JSON dokument",
+    "Microsoft Access database" : "Databáze Microsoft Access",
+    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
+    "Microsoft Word document" : "Dokument Microsoft Word",
+    "Unknown" : "Neznámé",
+    "PDF document" : "PDF dokument",
+    "PostScript document" : "PostScript dokument",
+    "RSS summary" : "RSS shrnutí",
+    "Android package" : "Balíček pro Android",
+    "KML geographic data" : "Geografická data KML",
+    "KML geographic compressed data" : "Komprimovaná KLM geografická data",
+    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
+    "Excel spreadsheet" : "Sešit Excel",
+    "Excel add-in" : "Doplněk do Excel",
+    "Excel 2007 binary spreadsheet" : "Sešit Excel 2007 (v binárním formátu)",
+    "Excel spreadsheet template" : "Šablona sešitu Excel",
+    "Outlook Message" : "Outlook zpráva",
+    "PowerPoint presentation" : "PowerPoint prezentace",
+    "PowerPoint add-in" : "Doplněk do PowerPoint",
+    "PowerPoint presentation template" : "Šablona prezentace PowerPoint",
+    "Word document" : "Dokument Word",
+    "ODF formula" : "ODF vzorec",
+    "ODG drawing" : "ODG kresba",
+    "ODG drawing (Flat XML)" : "Kresba ve formátu ODG (ploché XML)",
+    "ODG template" : "ODG šablona",
+    "ODP presentation" : "ODP prezentace",
+    "ODP presentation (Flat XML)" : "Prezentace ve formátu ODP (ploché XML)",
+    "ODP template" : "ODP šablona",
+    "ODS spreadsheet" : "ODS šablona",
+    "ODS spreadsheet (Flat XML)" : "Sešit ve formátu ODS (ploché XML)",
+    "ODS template" : "ODS šablona",
+    "ODT document" : "ODT dokument",
+    "ODT document (Flat XML)" : "Dokument ve formátu ODT (ploché XML)",
+    "ODT template" : "ODT šablona",
+    "PowerPoint 2007 presentation" : "Prezentace PowerPoint 2007",
+    "PowerPoint 2007 show" : "Show PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Šablona prezentace PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Sešit Excel 2007",
+    "Excel 2007 spreadsheet template" : "Šablona sešitu Excel 2007",
+    "Word 2007 document" : "Dokument Word 2007",
+    "Word 2007 document template" : "Šablona dokumentu Word 2007",
+    "Microsoft Visio document" : "Dokument Microsoft Visio",
+    "WordPerfect document" : "WordPerfect dolument",
+    "7-zip archive" : "7-zip archiv",
+    "Blender scene" : "Scéna v Blenderu",
+    "Bzip2 archive" : "Bzip2 archiv",
+    "Debian package" : "Debian balíček",
+    "FictionBook document" : "FictionBook dokument",
+    "Unknown font" : "Neznámé písmo",
+    "Krita document" : "Krita dokument",
+    "Mobipocket e-book" : "Mobipocket e-kniha",
+    "Windows Installer package" : "Balíček Windows instalátoru",
+    "Perl script" : "Perl skript",
+    "PHP script" : "PHP skript",
+    "Tar archive" : "Tar archiv",
+    "XML document" : "XML dokument",
+    "YAML document" : "YAML dokument",
+    "Zip archive" : "Zip archiv",
+    "Zstandard archive" : "Zstandard archiv",
+    "AAC audio" : "AAC audio",
+    "FLAC audio" : "FLAC audio",
+    "MPEG-4 audio" : "MPEG-4 audio",
+    "MP3 audio" : "MP3 audio",
+    "Ogg audio" : "Ogg audio",
+    "RIFF/WAVe standard Audio" : "Audio ve standardu RIFF/WAVe",
+    "WebM audio" : "WebM audio",
+    "MP3 ShoutCast playlist" : "Seznam stop MP3 ShoutCast",
+    "Windows BMP image" : "Windows BMP obrázek",
+    "Better Portable Graphics image" : "Obrázek ve formátu Beter Portable Graphics",
+    "EMF image" : "EMF obrázek",
+    "GIF image" : "GIF obrázek",
+    "HEIC image" : "HEIC obrázek",
+    "HEIF image" : "HEIF obrázek",
+    "JPEG-2000 JP2 image" : "Obrázek JPEG-2000 JP2",
+    "JPEG image" : "JPEG obrázek",
+    "PNG image" : "Obrázek PNG",
+    "SVG image" : "SVG obrázek",
+    "Truevision Targa image" : "Obrázek Truevision Targa",
+    "TIFF image" : "TIFF obrázek",
+    "WebP image" : "WebP obrázek",
+    "Digital raw image" : "Obrázek – digitální negativ",
+    "Windows Icon" : "Windows ikona",
+    "Email message" : "E-mailová zpráva",
+    "VCS/ICS calendar" : "VCS/ICS kalednář",
+    "CSS stylesheet" : "CSS kaskádové styly",
+    "CSV document" : "CSV dokument",
+    "HTML document" : "HTML dokument",
+    "Markdown document" : "Markdown dokument",
+    "Org-mode file" : "soubor Org-mode",
+    "Plain text document" : "Dokument neformátovaného textu",
+    "Rich Text document" : "Dokument typu Rich Text",
+    "Electronic business card" : "Elektronická vizitka",
+    "C++ source code" : "Zdrojový kód v C++",
+    "LDIF address book" : "LDIF adresář kontaktů",
+    "NFO document" : "NFO dokument",
+    "PHP source" : "PHP zdrojové kódy",
+    "Python script" : "Python skript",
+    "ReStructuredText document" : "ReStructuredText dokument",
+    "3GPP multimedia file" : "3GPP soubor multimédií",
+    "MPEG video" : "MPEG video",
+    "DV video" : "DV video",
+    "MPEG-2 transport stream" : "MPEG-2 transportní proud",
+    "MPEG-4 video" : "MPEG-4 video",
+    "Ogg video" : "Ogg video",
+    "QuickTime video" : "QuickTime video",
+    "WebM video" : "WebM video",
+    "Flash video" : "Flash video",
+    "Matroska video" : "Matroska video",
+    "Windows Media video" : "Windows Media video",
+    "AVI video" : "AVI video",
     "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Podrobnosti naleznete v {linkstart}dokumentaci ↗{linkend}.",
     "unknown text" : "neznámý text",
@@ -103,12 +224,12 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} upozornění","{count} upozornění","{count} upozornění","{count} upozornění"],
     "No" : "Ne",
     "Yes" : "Ano",
-    "Federated user" : "Federovaný uživatel",
-    "user@your-nextcloud.org" : "uzivatel@vas-nextcloud.org",
-    "Create share" : "Vytvořit sdílení",
     "The remote URL must include the user." : "Je třeba, aby vzdálená URL obsahovala uživatele.",
     "Invalid remote URL." : "Neplatná vzdálená URL.",
     "Failed to add the public link to your Nextcloud" : "Nepodařilo se přidání veřejného odkazu do Nextcloud",
+    "Federated user" : "Federovaný uživatel",
+    "user@your-nextcloud.org" : "uzivatel@vas-nextcloud.org",
+    "Create share" : "Vytvořit sdílení",
     "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
     "Please copy the link manually:" : "Zkopírujte odkaz ručně:",
     "Custom date range" : "Uživatelsky určené datumové rozmezí",
@@ -118,56 +239,61 @@ OC.L10N.register(
     "Search in current app" : "Hledat ve stávající aplikaci",
     "Clear search" : "Vyčistit hledání",
     "Search everywhere" : "Hledat všude",
-    "Unified search" : "Sjednocené vyhledávání",
-    "Search apps, files, tags, messages" : "Prohledat aplikace, soubory, štítky a zprávy",
-    "Places" : "Místa",
-    "Date" : "Datum",
+    "Searching …" : "Hledání…",
+    "Start typing to search" : "Hledejte psaním",
+    "No matching results" : "Žádné odpovídající výsledky",
     "Today" : "Dnes",
     "Last 7 days" : "Uplynulých 7 dnů",
     "Last 30 days" : "Uplynulých 30 dnů",
     "This year" : "Tento rok",
     "Last year" : "Uplynulý rok",
+    "Unified search" : "Sjednocené vyhledávání",
+    "Search apps, files, tags, messages" : "Prohledat aplikace, soubory, štítky a zprávy",
+    "Places" : "Místa",
+    "Date" : "Datum",
     "Search people" : "Hledat osoby",
     "People" : "Lidé",
     "Filter in current view" : "Filtrovat ve stávajícím pohledu",
     "Results" : "Výsledky",
     "Load more results" : "Načíst další výsledky",
     "Search in" : "Hledat v",
-    "Searching …" : "Hledání…",
-    "Start typing to search" : "Hledejte psaním",
-    "No matching results" : "Žádné odpovídající výsledky",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Mezi ${this.dateFilter.startFrom.toLocaleDateString()} a ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Přihlásit",
     "Logging in …" : "Přihlašování…",
-    "Server side authentication failed!" : "Ověření se na straně serveru se nezdařilo!",
-    "Please contact your administrator." : "Obraťte se na svého správce.",
-    "Temporary error" : "Chvilková chyba",
-    "Please try again." : "Zkuste to znovu.",
-    "An internal error occurred." : "Došlo k vnitřní chybě.",
-    "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na správce.",
-    "Password" : "Heslo",
     "Log in to {productName}" : "Přihlásit se do {productName}",
     "Wrong login or password." : "Nesprávné přihlašovací jméno nebo heslo",
     "This account is disabled" : "Účet je znepřístupněn",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bylo rozpoznáno několik neplatných pokusů o přihlášeni z vaší IP adresy. Další přihlášení bude možné za 30 sekund.",
     "Account name or email" : "Název účtu nebo e-mail",
     "Account name" : "Název účtu",
+    "Server side authentication failed!" : "Ověření se na straně serveru se nezdařilo!",
+    "Please contact your administrator." : "Obraťte se na svého správce.",
+    "Session error" : "Chyba relace",
+    "It appears your session token has expired, please refresh the page and try again." : "Zdá se, že platnost vašeho tokenu relace skončila – načtěte stránku znovu a zkuste znovu, o co jste se pokoušeli.",
+    "An internal error occurred." : "Došlo k vnitřní chybě.",
+    "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na správce.",
+    "Password" : "Heslo",
     "Log in with a device" : "Přihlásit se pomocí zařízení",
     "Login or email" : "Přihlašovací jméno nebo e-mail",
     "Your account is not setup for passwordless login." : "Váš účet nemá nastavené přihlašování se bez hesla.",
-    "Browser not supported" : "Prohlížeč není podporován",
-    "Passwordless authentication is not supported in your browser." : "Přihlašování se bez hesla není ve vámi používaném prohlížeči podporováno.",
     "Your connection is not secure" : "Vaše připojení není zabezpečené",
     "Passwordless authentication is only available over a secure connection." : "Ověření se bez hesla je k dispozici pouze přes zabezpečené připojení.",
+    "Browser not supported" : "Prohlížeč není podporován",
+    "Passwordless authentication is not supported in your browser." : "Přihlašování se bez hesla není ve vámi používaném prohlížeči podporováno.",
     "Reset password" : "Resetovat heslo",
+    "Back to login" : "Zpět na přihlášení",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Pokud tento účet existuje, byla na jeho e-mailovou adresu odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, zkontrolujte správnost zadání e-mailové adresy a/nebo přihlašovacího jména, dále se podívejte také do složek s nevyžádanou poštou (spam). Případně požádejte svého místního správce o pomoc.",
     "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat e-mail pro změnu hesla. Obraťte se na správce.",
     "Password cannot be changed. Please contact your administrator." : "Heslo nelze změnit. Obraťte se na svého správce systému.",
-    "Back to login" : "Zpět na přihlášení",
     "New password" : "Nové heslo",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše soubory jsou šifrované. Vyresetováním hesla nebude způsob, jak získat vaše data zpět. Pokud nevíte, co dělat, nepokračujte a obraťte se na svého správce. Opravdu chcete pokračovat?",
     "I know what I'm doing" : "Vím co dělám",
     "Resetting password" : "Resetuje se heslo",
+    "Schedule work & meetings, synced with all your devices." : "Plánujte si práci a schůzky – synchronizováno napříč všemi vašimi zařízeními.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Uchovávejte si údaje svých kolegů a přátel na jednom místě, aniž by k jejim osobním údajům získal přístup někdo jiný.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchý e-mailový klient, propojený s aplikacemi Soubory, Kontakty a Kalendář.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
+    "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
     "Recommended apps" : "Doporučené aplikace",
     "Loading apps …" : "Načítání aplikací…",
     "Could not fetch list of apps from the App Store." : "Nedaří se získat seznam aplikací z katalogu.",
@@ -177,14 +303,10 @@ OC.L10N.register(
     "Skip" : "Přeskočit",
     "Installing apps …" : "Instalace aplikací…",
     "Install recommended apps" : "Nainstalovat doporučené aplikace",
-    "Schedule work & meetings, synced with all your devices." : "Plánujte si práci a schůzky – synchronizováno napříč všemi vašimi zařízeními.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Uchovávejte si údaje svých kolegů a přátel na jednom místě, aniž by k jejim osobním údajům získal přístup někdo jiný.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchý e-mailový klient, propojený s aplikacemi Soubory, Kontakty a Kalendář.",
-    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
-    "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
-    "Settings menu" : "Nabídka nastavení",
     "Avatar of {displayName}" : "Zástupný obrázek {displayName}",
+    "Settings menu" : "Nabídka nastavení",
+    "Loading your contacts …" : "Načítání vašich kontaktů…",
+    "Looking for {term} …" : "Hledání {term}…",
     "Search contacts" : "Hledat v kontaktech",
     "Reset search" : "Resetovat hledání",
     "Search contacts …" : "Hledat v kontaktech…",
@@ -192,26 +314,66 @@ OC.L10N.register(
     "No contacts found" : "Nenalezeny žádné kontakty",
     "Show all contacts" : "Zobrazit všechny kontakty",
     "Install the Contacts app" : "Nainstalovat aplikaci Kontakty",
-    "Loading your contacts …" : "Načítání vašich kontaktů…",
-    "Looking for {term} …" : "Hledání {term}…",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "Hledání začne jakmile začnete psát a mezi výsledky je možné se pohybovat pomocí klávesami šipka nahoru/dolů",
-    "Search for {name} only" : "Hledat pouze {name}",
-    "Loading more results …" : "Načítání dalších výsledků…",
     "Search" : "Hledat",
     "No results for {query}" : "Pro {query} nic nenalezeno",
     "Press Enter to start searching" : "Vyhledávání zahájíte stisknutím klávesy Enter",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znak","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaků","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky"],
     "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Hledání začne jakmile začnete psát a mezi výsledky je možné se pohybovat pomocí klávesami šipka nahoru/dolů",
+    "Search for {name} only" : "Hledat pouze {name}",
+    "Loading more results …" : "Načítání dalších výsledků…",
     "Forgot password?" : "Zapomněli jste heslo?",
     "Back to login form" : "Zpět na formulář pro přihlášení",
     "Back" : "Zpět",
     "Login form is disabled." : "Formulář pro přihlášení je vypnut",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
     "More actions" : "Další akce",
+    "User menu" : "Nabídka uživatele",
+    "You will be identified as {user} by the account owner." : "Vlastníkem účtu budete identifikováni jako {user}.",
+    "You are currently not identified." : "V tuto chvíli nejste identifikováni.",
+    "Set public name" : "Nastavit veřejné jméno",
+    "Change public name" : "Změnit veřejné jméno",
+    "Password is too weak" : "Heslo je příliš snadno prolomitelné",
+    "Password is weak" : "Heslo je snadno prolomitelné",
+    "Password is average" : "Heslo je postačující",
+    "Password is strong" : "Heslo je odolné",
+    "Password is very strong" : "Heslo je velmi odolné",
+    "Password is extremely strong" : "Heslo je extrémně odolné",
+    "Unknown password strength" : "Neznámá odolnost hesla",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor <code>.htaccess</code> nefunguje.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informace o tom, jak správně nastavit váš server, naleznete v {linkStart}dokumentaci{linkEnd}",
+    "Autoconfig file detected" : "Zjištěn soubor s automatického nastavení",
+    "The setup form below is pre-filled with the values from the config file." : "Níže uvedený formulář nastavení je předvyplněný hodnotami ze souboru s nastaveními.",
+    "Security warning" : "Varování ohledně zabezpečení",
+    "Create administration account" : "Vytvořit účet pro správnu",
+    "Administration account name" : "Název účtu pro správu",
+    "Administration account password" : "Heslo k účtu pro správu",
+    "Storage & database" : "Úložiště a databáze",
+    "Data folder" : "Složka s daty",
+    "Database configuration" : "Nastavení databáze",
+    "Only {firstAndOnlyDatabase} is available." : "K dispozici je pouze {firstAndOnlyDatabase}.",
+    "Install and activate additional PHP modules to choose other database types." : "Pokud chcete vybrat jiné typy databáze, je třeba nainstalovat a povolit dodatečné PHP moduly.",
+    "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
+    "Performance warning" : "Varování ohledně výkonu",
+    "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro instance, které slouží jen pro vývoj nebo ty obhospodařující opravdu velmi málo dat a uživatelů. Pro jakékoli produkční použití doporučujeme použít robustnější databázové řešení.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
+    "Database user" : "Uživatel databáze",
+    "Database password" : "Heslo do databáze",
+    "Database name" : "Název databáze",
+    "Database tablespace" : "Tabulkový prostor databáze",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
+    "Database host" : "Stroj na kterém se nachází databáze",
+    "localhost" : "localhost",
+    "Installing …" : "Instalace…",
+    "Install" : "Nainstalovat",
+    "Need help?" : "Potřebujete nápovědu?",
+    "See the documentation" : "Viz dokumentace",
+    "{name} version {version} and above" : "{name} verze {version} a novější",
     "This browser is not supported" : "Tento prohlížeč není podporován",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
     "Continue with this unsupported browser" : "Pokračovat s tímto zastaralým prohlížečem",
     "Supported versions" : "Podporované verze",
-    "{name} version {version} and above" : "{name} verze {version} a novější",
     "Search {types} …" : "Hledat {types}…",
     "Choose {file}" : "Zvolit {file}",
     "Choose" : "Vybrat",
@@ -247,11 +409,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Psaním vyhledávejte existující projekty",
     "New in" : "Nové v",
     "View changelog" : "Zobrazit souhrn změn",
-    "Very weak password" : "Velmi snadno prolomitelné heslo",
-    "Weak password" : "Snadno prolomitelné heslo",
-    "So-so password" : "Ještě použitelné heslo",
-    "Good password" : "Dobré heslo",
-    "Strong password" : "Odolné heslo",
     "No action available" : "Není dostupná žádná akce",
     "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
     "Close \"{dialogTitle}\" dialog" : "Zavřít „{dialogTitle}“ dialog",
@@ -269,9 +426,10 @@ OC.L10N.register(
     "Admin" : "Správa",
     "Help" : "Nápověda",
     "Access forbidden" : "Přístup zakázán",
+    "You are not allowed to access this page." : "Nemáte oprávnění k přístupu k této stránce.",
+    "Back to %s" : "Zpět na %s",
     "Page not found" : "Stránka nenalezena",
     "The page could not be found on the server or you may not be allowed to view it." : "Stránku se na serveru nepodařilo nalézt nebo nemáte oprávnění ji zobrazit.",
-    "Back to %s" : "Zpět na %s",
     "Too many requests" : "Příliš mnoho požadavků",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Z vaší sítě bylo příliš mnoho požadavků. Zkuste to později nebo (pokud je toto chyba) se obraťte na svého správce.",
     "Error" : "Chyba",
@@ -289,34 +447,6 @@ OC.L10N.register(
     "File: %s" : "Soubor: %s",
     "Line: %s" : "Řádek: %s",
     "Trace" : "Trace",
-    "Security warning" : "Varování ohledně zabezpečení",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
-    "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
-    "New admin account name" : "Název účtu nového správce",
-    "New admin password" : "Heslo nového správce",
-    "Show password" : "Zobrazit heslo",
-    "Toggle password visibility" : "Přepnout viditelnost hesla",
-    "Storage & database" : "Úložiště a databáze",
-    "Data folder" : "Složka s daty",
-    "Configure the database" : "Nastavit databázi",
-    "Only %s is available." : "Je k dispozici pouze %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Pokud chcete vybrat jiné typy databáze, je třeba nainstalovat a povolit dodatečné PHP moduly.",
-    "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
-    "Database account" : "Účet do databáze",
-    "Database password" : "Heslo do databáze",
-    "Database name" : "Název databáze",
-    "Database tablespace" : "Tabulkový prostor databáze",
-    "Database host" : "Stroj na kterém se nachází databáze",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
-    "Performance warning" : "Varování ohledně výkonu",
-    "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro instance, které slouží jen pro vývoj nebo ty obhospodařující opravdu velmi málo dat a uživatelů. Pro jakékoli produkční použití doporučujeme použít robustnější databázové řešení.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
-    "Install" : "Nainstalovat",
-    "Installing …" : "Instalace…",
-    "Need help?" : "Potřebujete nápovědu?",
-    "See the documentation" : "Viz dokumentace",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Zdá se, že se pokoušíte přeinstalovat svou instanci NextCloud. Nicméně ve vašem adresáři s nastaveními chybí soubor CAN_INSTALL. Aby bylo možné pokračovat, takový tam vytvořte.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nedaří se ze složky s nastaveními odstranit soubor CAN_INSTALL. Odstraňte ho proto ručně.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tato aplikace potřebuje pro správnou funkčnost JavaScript. {linkstart}Povolte ho{linkend} a stránku znovu načtěte.",
@@ -375,17 +505,28 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
     "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje trvale nebo nečekaně, obraťte se na správce systému.",
-    "Currently open" : "Nyní otevřeno",
-    "Login with username or email" : "Přihlásit se uživatelským jménem nebo e-mailem",
-    "Login with username" : "Přihlásit se uživatelským jménem",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
-    "Edit Profile" : "Upravit profil",
-    "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
     "You have not added any info yet" : "Zatím jste nezadali žádné informace",
     "{user} has not added any info yet" : "{user} uživatel zatím nezadal žádné informace",
     "Error opening the user status modal, try hard refreshing the page" : "Chyba při otevírání dialogu stavu uživatele, pokus o opětovné načtení stránky",
-    "Error loading message template: {error}" : "Chyba při načítání šablony zprávy: {error}",
+    "Edit Profile" : "Upravit profil",
+    "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
+    "Very weak password" : "Velmi snadno prolomitelné heslo",
+    "Weak password" : "Snadno prolomitelné heslo",
+    "So-so password" : "Ještě použitelné heslo",
+    "Good password" : "Dobré heslo",
+    "Strong password" : "Odolné heslo",
     "Profile not found" : "Profil nenalezen",
-    "The profile does not exist." : "Profil neexistuje."
+    "The profile does not exist." : "Profil neexistuje.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
+    "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
+    "New admin account name" : "Název účtu nového správce",
+    "New admin password" : "Heslo nového správce",
+    "Show password" : "Zobrazit heslo",
+    "Toggle password visibility" : "Přepnout viditelnost hesla",
+    "Configure the database" : "Nastavit databázi",
+    "Only %s is available." : "Je k dispozici pouze %s.",
+    "Database account" : "Účet do databáze"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
