@@ -328,6 +328,11 @@ OC.L10N.register(
     "Login form is disabled." : "Sisselogimise leht on keelatud.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudi sisselogimisvorm on kasutusel eemaldatud. Kui mõni muu sisselogimisviis on saadaval, siis kasuta seda või küsi lisateavet oma süsteemihaldajalt.",
     "More actions" : "Täiendavad tegevused",
+    "User menu" : "Kasutajamenüü",
+    "You will be identified as {user} by the account owner." : "Kasutajakonto omanik tuvastab sind hetkel, kui {user}",
+    "You are currently not identified." : "Sa pole hetkel tuvastatud",
+    "Set public name" : "Lisa avalik nimi",
+    "Change public name" : "Muuda avalikku nime",
     "Password is too weak" : "Salasõna on liiga nõrk",
     "Password is weak" : "Salasõna on nõrk",
     "Password is average" : "Salasõna on keskpärane",
