@@ -44,6 +44,7 @@ OC.L10N.register(
     "Task not found" : "Úloha nebola nájdená",
     "Internal error" : "Interná chyba",
     "Not found" : "Nenájdené",
+    "Node is locked" : "Uzol je uzamknutý",
     "Bad request" : "Neplatná požiadavka",
     "Requested task type does not exist" : "Vyžiadaný typ úlohy neexistuje",
     "Necessary language model provider is not available" : "Potrebný poskytovateľ jazykového modelu nie je dostupný",
@@ -80,7 +81,81 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekompatibilná)",
     "The following apps have been disabled: %s" : "Nasledujúce aplikácie boli vypnuté: %s",
     "Already up to date" : "Už aktuálne",
+    "Electronic book document" : "Dokument elektronickej knihy",
+    "TrueType Font Collection" : "Kolekcia fontov TrueType",
+    "GPX geographic data" : "GPX geografické dáta",
+    "Gzip archive" : "Gzip archív",
+    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
+    "Java source code" : "Zdrojový kód Java",
+    "JavaScript source code" : "Zdrojový kód Javascriptu",
+    "JSON document" : "Dokument JSON",
+    "Microsoft Access database" : "Databáza Microsoft Access",
+    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
+    "Microsoft Word document" : "Dokument Microsoft Word",
     "Unknown" : "Neznámy",
+    "PDF document" : "PDF dokument",
+    "PostScript document" : "Dokument PostScriptu",
+    "RSS summary" : "Zhrnutie RSS",
+    "Android package" : "Balík pre Android",
+    "KML geographic data" : "KML geografické dáta",
+    "KML geographic compressed data" : "KML komprimované geografické dáta",
+    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
+    "Excel spreadsheet" : "Tabuľka Excelu",
+    "Excel add-in" : "Rozšírenie Excelu",
+    "Excel 2007 binary spreadsheet" : "Binárna tabuľka Excel 2007",
+    "Excel spreadsheet template" : "Šablóna tabuľky Excel",
+    "Outlook Message" : "Správa Outlooku",
+    "PowerPoint presentation" : "PowerPoint prezentácia",
+    "PowerPoint add-in" : "Rozšírenie PowerPointu",
+    "PowerPoint presentation template" : "Šablóna prezentácie PowerPoint",
+    "Word document" : "Dokument Wordu",
+    "ODF formula" : "Vzorec ODF",
+    "ODG drawing" : "Kresba ODG",
+    "ODG drawing (Flat XML)" : "Výkres ODG (Čisté XML)",
+    "ODG template" : "Šablóna ODG",
+    "ODP presentation" : "Prezentácia ODP",
+    "ODP presentation (Flat XML)" : "Prezentácia ODP (Čisté XML)",
+    "ODP template" : "Šablóna ODP",
+    "ODS spreadsheet" : "Tabuľka ODS",
+    "ODS spreadsheet (Flat XML)" : "Tabuľka ODS (Čisté XML)",
+    "ODS template" : "Šablóna ODS",
+    "ODT document" : "Dokument ODT",
+    "ODT document (Flat XML)" : "Dokument ODT (Čisté XML)",
+    "ODT template" : "Šablóna ODT",
+    "PowerPoint 2007 presentation" : "Prezentácia PowerPointu 2007",
+    "PowerPoint 2007 show" : "Prezentácia PowerPointu 2007",
+    "PowerPoint 2007 presentation template" : "Šablóna prezentácie PowerPointu 2007",
+    "Excel 2007 spreadsheet" : "Tabuľka Excelu 2007",
+    "Excel 2007 spreadsheet template" : "Šablóna tabuľky Excelu 2007",
+    "Word 2007 document" : "Dokument Wordu 2007",
+    "Word 2007 document template" : "Šablóna dokumentu Wordu 2007",
+    "Microsoft Visio document" : "Dokument Microsoft Visio",
+    "WordPerfect document" : "Dokument WordPerfectu",
+    "7-zip archive" : "7-zip archív",
+    "Blender scene" : "Scéna Blenderu",
+    "Bzip2 archive" : "Bzip2 archív",
+    "Debian package" : "Balík Debianu",
+    "FictionBook document" : "Dokument FictionBook",
+    "Unknown font" : "Neznáme písmo",
+    "Krita document" : "Dokument Krita",
+    "Mobipocket e-book" : "E-kniha Mobipocket",
+    "Windows Installer package" : "Inštalačný balík Windows",
+    "Perl script" : "Skript Perlu",
+    "PHP script" : "Skript PHP",
+    "Tar archive" : "Archív TAR",
+    "XML document" : "Dokument XML",
+    "YAML document" : "Dokument YAML",
+    "Zip archive" : "Zip archív",
+    "Zstandard archive" : "Zstandartd archív",
+    "AAC audio" : "AAC audio",
+    "FLAC audio" : "FLAC audio",
+    "MPEG-4 audio" : "MPEG-4 audio",
+    "MP3 audio" : "MP3 audio",
+    "Ogg audio" : "Ogg audio",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe standard Audio",
+    "WebM audio" : "WebM audio",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
+    "Windows BMP image" : "Obrázok Windows BMP",
     "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
     "unknown text" : "neznámy text",
